<?php
# Ubuntu Manual
# Copyright (C) 2010 Daker <adnane002@gmail.com>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

/* CORE */
function import($name) {
	$file = PATH.'includes/'.$name.'.php';
	if(file_exists($file)) require_once $file;
}

/* GETTEXT STUFF (WORDPRESS) */
function __($string, $js = false) {
    global $gettext_tables;
    #$file = 'debug.log';
    #$fp = fopen($file, 'a');
    #fputs($fp, "#: pages/getinvolved.php:\n");
    #fputs($fp, "msgid \"$string\"\n");
    #fputs($fp, "msgstr \"\"\n\n");
    #fclose($fp);
    if (!$gettext_tables) {
    	if ($js) return str_replace("'", "\\"."'", $string);
    	else return $string;
    }
    else {
    	if ($js) return str_replace("'", "\\"."'", $gettext_tables->translate($string));
		else return $gettext_tables->translate($string);
    }
}

function url_exists($strURL) { 
    $resURL = curl_init(); 
    curl_setopt($resURL, CURLOPT_URL, $strURL); 
    curl_setopt($resURL, CURLOPT_BINARYTRANSFER, 1); 
    curl_setopt($resURL, CURLOPT_HEADERFUNCTION, 'curlHeaderCallback'); 
    curl_setopt($resURL, CURLOPT_FAILONERROR, 1); 

    curl_exec ($resURL); 

    $intReturnCode = curl_getinfo($resURL, CURLINFO_HTTP_CODE); 
    curl_close ($resURL); 

    if ($intReturnCode != 200 && $intReturnCode != 302 && $intReturnCode != 304) { 
       return false; 
    }Else{ 
        return true ; 
    } 
} 


function set_language($lang)
{
	global $gettext_tables;
	if (file_exists(PATH.'includes/languages/'.$lang.'/LC_MESSAGES/'.$lang.'.mo')) {	
		$gettext_tables = new gettext_reader(new CachedFileReader(PATH.'includes/languages/'.$lang.'/LC_MESSAGES/'.$lang.'.mo'));
   		$gettext_tables->load_tables();
	}
}



// Converts an IP to a 2 letter country code, using GeoIP database if available in includes/geo/
function geo_ip_to_countrycode( $ip = '', $default = '' ) {
	if ( !file_exists( dirname(__FILE__).'/geo/GeoIP.dat') || !file_exists( dirname(__FILE__).'/geo/geoip.inc') )
		return $default;

	if ( $ip == '' )
		$ip = get_IP();
		
	require_once( dirname(__FILE__).'/geo/geoip.inc') ;
	$gi = geoip_open( dirname(__FILE__).'/geo/GeoIP.dat', GEOIP_STANDARD);
	$location = geoip_country_code_by_addr($gi, $ip);
	geoip_close($gi);

	return $location;
}

// Converts a 2 letter country code to long name (ie AU -> Australia)
function geo_countrycode_to_countryname( $code ) {
	// Load the Geo class if not already done
	if( !class_exists('GeoIP') ) {
		$temp = geo_ip_to_countrycode('127.0.0.1');
	}
	
	if( class_exists('GeoIP') ) {
		$geo = new GeoIP;
		$id = $geo->GEOIP_COUNTRY_CODE_TO_NUMBER[$code];
		$long = $geo->GEOIP_COUNTRY_NAMES[$id];
		return $long;
	} else {
		return false;
	}
}

// Return flag URL from 2 letter country code
function geo_get_flag( $code ) {
	// Load the Geo class if not already done
	if( !class_exists('GeoIP') ) {
		$temp = geo_ip_to_countrycode('127.0.0.1');
	}
	
	if( class_exists('GeoIP') ) {
		return SITE.'/includes/geo/flags/flag_'.(strtolower($code)).'.gif';
	} else {
		return false;
	}
}

// Function: Get IP Address. Returns a DB safe string.
function get_IP() {
	if( !empty( $_SERVER['REMOTE_ADDR'] ) ) {
		$ip = $_SERVER['REMOTE_ADDR'];
	} else {
		if(!empty($_SERVER['HTTP_CLIENT_IP'])) {
			$ip = $_SERVER['HTTP_CLIENT_IP'];
		} else if(!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
			$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
		} else if(!empty($_SERVER['HTTP_VIA '])) {
			$ip = $_SERVER['HTTP_VIA '];
		}
	}

	return $ip ;
}

// Returns a sanitized a user agent string. Given what I found on http://www.user-agents.org/ it should be OK.
function get_user_agent() {
	if ( !isset( $_SERVER['HTTP_USER_AGENT'] ) )
		return '-';
	
	$ua = strip_tags( html_entity_decode( $_SERVER['HTTP_USER_AGENT'] ));
	$ua = preg_replace('![^0-9a-zA-Z\':., /{}\(\)\[\]\+@&\!\?;_\-=~\*\#]!', '', $ua );
		
	return substr( $ua, 0, 254 );
}

// Given a language code, we'll return the URL for the print edition of the latest version of the manual in that language
function get_latest_buy_url($lulu_manuals, $language_short_code, $language_code = "") {
	$version = get_latest_lulu_version($lulu_manuals, $language_short_code, $language_code);

	if (!isset($lulu_manuals[$version][$language_short_code]) && !isset($lulu_manuals[$version][$language_code])) {
		//echo "<!-- lulu manual doesn't exist. falling back on en_US manual -->\n";
		$language_short_code = "en_US";
	}

	$url = '/buy/' . $version . '/' . $language_short_code;
	return $url;
}

// Given a language code, we'll return the URL for the screen version of the latest edition of the manual in that language
function get_latest_manual_url($available_manuals, $language_short_code, $language_code = "") {
	$version = get_latest_version($available_manuals, $language_short_code, $language_code);

	if (!isset($available_manuals[$version][$language_short_code]) && !isset($available_manuals[$version][$language_code])) {
		$language_short_code = "en_US";
	}

	$url = BASE . '/download/' . $version . '/' . $language_short_code . '/screen';
	return $url;
}

function get_latest_lulu_version($lulu_manuals, $language_short_code, $language_code = "") {
	// Find all versions of the manual in $language_short_code or $language_code
	$versions = array();
	foreach ($lulu_manuals as $ver => $language_titles) {
		if (isset($lulu_manuals[$ver][$language_short_code]) || isset($lulu_manuals[$ver][$language_code])) {
			$versions[] = $ver;
		}
	}

	// Of the versions found, return the latest version
	if (count($versions) > 0) {
		natsort($versions);
		return $versions[count($versions) - 1];
	} else {
		// If there's no translated version of the manual in $language_code,
		// return the latest US English edition.
		return get_latest_lulu_version($lulu_manuals, "en_US");
	}
}

function get_latest_version($available_manuals, $language_short_code, $language_code = "") {
	$versions = array();
	foreach ($available_manuals as $ver => $language_titles) {
		if (isset($available_manuals[$ver][$language_short_code]) || isset($available_manuals[$ver][$language_code])) {
			$versions[] = $ver;
		}
	}

	if (count($versions) > 0) {
		natsort($versions);
		return $versions[count($versions) - 1];
	} else {
		// If there's no translated version of the manual in $language_code,
		// return the latest US English edition.
		return get_latest_version($available_manuals, "en_US");
	}
}

function get_latest_title($available_manuals, $language_short_code, $language_code = "") {
	$latest_version = get_latest_version($available_manuals, $language_short_code, $language_code);

	$title = $available_manuals[get_latest_version($available_manuals, "en_US")]["en_US"];
	if (isset($available_manuals[$latest_version][$language_short_code])) {
		$title = $available_manuals[$latest_version][$language_short_code];
	} elseif (isset($available_manuals[$latest_version][$language_code])) {
		$title = $available_manuals[$latest_version][$language_code];
	}

	$title = substr($title, 0, -4); // strip off .pdf extension
	echo "\n<!-- lang = $language_short_code / title = $title -->\n";
	return $title;
}

?>
